pub struct TransactionPackageStore<'a> { /* private fields */ }Expand description
A TransactionPackageStore is a ModuleResolver that fetches packages from a backing store.
It also tracks packages that are being published in the current transaction and allows
“loading” of those packages as well.
It is used to provide package loading (from storage) for the Move VM.
Implementations
Sourceimpl<'a> TransactionPackageStore<'a>
impl<'a> TransactionPackageStore<'a>
pub fn new(package_store: &'a dyn BackingPackageStore) -> Self
Sourcepub fn push_package(
&self,
id: ObjectID,
package: Rc<MovePackage>,
verified_package: VerifiedPackage,
) -> Result<(), ExecutionError>
pub fn push_package( &self, id: ObjectID, package: Rc<MovePackage>, verified_package: VerifiedPackage, ) -> Result<(), ExecutionError>
Push a new package into the new packages. This is used to track packages that are being published or have been published.
Sourcepub fn pop_package(
&self,
id: ObjectID,
) -> Result<Arc<VerifiedPackage>, ExecutionError>
pub fn pop_package( &self, id: ObjectID, ) -> Result<Arc<VerifiedPackage>, ExecutionError>
Rollback a package that was pushed into the new packages. We keep the invariant that:
- You can only pop the most recent package that was pushed.
- The element being popped must exist in the new packages.
Otherwise this returns an invariant violation.
Sourcepub fn fetch_new_package(
&self,
id: &ObjectID,
) -> Option<(Rc<MovePackage>, Arc<VerifiedPackage>)>
pub fn fetch_new_package( &self, id: &ObjectID, ) -> Option<(Rc<MovePackage>, Arc<VerifiedPackage>)>
Fetch a package that is being published in the current transaction, if it exists. This does not look in the backing store.
Sourcepub fn to_new_packages(&self) -> Vec<MovePackage>
pub fn to_new_packages(&self) -> Vec<MovePackage>
Return all new packages that have been added to this store in the transaction.
Sourcepub fn fetch_move_package(
&self,
package_version_id: VersionId,
) -> SuiResult<Option<Rc<MovePackage>>>
pub fn fetch_move_package( &self, package_version_id: VersionId, ) -> SuiResult<Option<Rc<MovePackage>>>
Fetch a package by its version ID. This will first look in the new packages, and then in
the cache for any packages that have been loaded this transaction, and then in the backing store.
If found, it will be returned as a [MovePackage].